@@ -91,8 +91,9 @@ find_xy_col <- function (graph, indx, x = TRUE)
     } else
     {
         coli <- grep ("y|lat", names (graph) [indx], ignore.case = TRUE)
-        if (length (coli) > 1) # silicate still only matches once here, so nocov:
-            coli <- grep ("y$", names (graph) [indx], ignore.case = TRUE) # nocov
+        if (length (coli) > 1) # silicate only matches once here, so nocov:
+            coli <- grep ("y$", names (graph) [indx],       # nocov
+                          ignore.case = TRUE)               # nocov
     }
 
     indx [coli]
@@ -221,7 +222,7 @@ find_xy_col_simple <- function (dfr)
 #' matrix or \pkg{sf}-formatted `data.frame`.
 #' @param connected Should points be matched to the same (largest) connected
 #' component of graph? If `FALSE` and these points are to be used for a
-#' `dodgr` routine routine (\link{dodgr_dists}, \link{dodgr_paths}, or
+#' `dodgr` routing routine (\link{dodgr_dists}, \link{dodgr_paths}, or
 #' \link{dodgr_flows_aggregate}), then results may not be returned if points are
 #' not part of the same connected component. On the other hand, forcing them to
 #' be part of the same connected component may decrease the spatial accuracy of
@@ -247,8 +248,8 @@ match_pts_to_graph <- function (verts, xy, connected = FALSE)
     if (!all (c ("id", "x", "y") %in% names (verts)))
     {
         message ("First argument to match_pts_to_graph should be result of ",
-                 "dodgr_vertices;\npresuming you've submitted the network itself ",
-                 "and will now try extracting the vertices")
+                 "dodgr_vertices;\npresuming you've submitted the network ",
+                 "itself and will now try extracting the vertices")
         verts <- dodgr_vertices (verts)
     }
     if (!(is.matrix (xy) | is.data.frame (xy)))
@@ -306,8 +307,9 @@ match_points_to_graph <- function (verts, xy, connected = FALSE)
 remap_verts_with_turn_penalty <- function (graph, pts, from = TRUE)
 {
     if (!is (graph, "dodgr_streetnet_sc"))
-        stop ("vertices with turn angles can only be re-mapped for street ",      # nocov
-              "networks obtained via 'dodgr_streetnet_sc' -> 'weight_streetnet'") # nocov
+        stop ("vertices with turn angles can only be re-mapped for ",   # nocov
+              "street networks obtained via 'dodgr_streetnet_sc' -> ",  # nocov
+              "'weight_streetnet'")                                     # nocov
 
     suffix <- ifelse (from, "_start", "_end")
     suffix_rgx <- paste0 (suffix, "$")
