@@ -26,7 +26,7 @@ dodgr_times <- function (graph, from = NULL, to = NULL, shortest = FALSE,
         if (is.na (gr_cols$time_weighted))
             stop ("Graph does not contain a weighted time column from ",
                   "which to calculate fastest paths.")
-        graph [[gr_cols$w]] <- graph [[gr_cols$time_weighted]]
+        graph [[gr_cols$d_weighted]] <- graph [[gr_cols$time_weighted]]
     }
 
     dodgr_dists (graph, from, to, heap = heap)
