@@ -91,6 +91,8 @@ struct edge_t
     public:
         double dist;
         double weight;
+        double time;
+        double timew;
         bool replaced_by_compact;
 
         vertex_id_t get_from_vertex () { return from; }
@@ -99,14 +101,19 @@ struct edge_t
         std::set <edge_id_t> get_old_edges () { return old_edges; }
 
         edge_t (vertex_id_t from_id, vertex_id_t to_id,
-                double dist_in, double weight_in, edge_id_t id_in,
+                std::vector <double> weights_in, edge_id_t id_in,
                 std::set <edge_id_t> replacement_edges)
         {
             replaced_by_compact = false;
             this -> to = to_id;
             this -> from = from_id;
-            this -> dist = dist_in;
-            this -> weight = weight_in;
+            this -> dist = this -> weight = this -> time = weights_in [0];
+            if (weights_in.size () > 1)
+                this -> weight = weights_in [1];
+            if (weights_in.size () > 2)
+                this -> time = weights_in [2];
+            if (weights_in.size () > 3)
+                this -> timew = weights_in [3];
             this -> id = id_in;
             this -> old_edges.insert (replacement_edges.begin (),
                     replacement_edges.end ());
@@ -133,7 +140,7 @@ void erase_from_v2e_map (vert2edge_map_t &vert2edge_map, const vertex_id_t vid,
 
 bool graph_has_components (const Rcpp::DataFrame &graph);
 
-void graph_from_df (const Rcpp::DataFrame &gr, vertex_map_t &vm,
+bool graph_from_df (const Rcpp::DataFrame &gr, vertex_map_t &vm,
         edge_map_t &edge_map, vert2edge_map_t &vert2edge_map);
 
 unsigned int identify_graph_components (vertex_map_t &v,
@@ -186,14 +193,16 @@ void contract_one_edge (vert2edge_map_t &vert2edge_map,
         const vertex_id_t vtx_id, const vertex_id_t vt_from,
         const vertex_id_t vt_to,
         const edge_id_t edge_from_id, const edge_id_t edge_to_id,
-        const edge_id_t new_edge_id);
+        const edge_id_t new_edge_id,
+        bool has_times);
 
 bool same_hwy_type (const edge_map_t &edge_map, const edge_id_t &e1,
         const edge_id_t &e2);
 
 void contract_graph (vertex_map_t &vertex_map, edge_map_t &edge_map,
         vert2edge_map_t &vert2edge_map,
-        std::unordered_set <vertex_id_t> verts_to_keep);
+        std::unordered_set <vertex_id_t> verts_to_keep,
+        bool has_times);
 
 } // end namespace graph_contract
 
