@@ -93,6 +93,12 @@ class PathFinder {
                 std::vector<int>& prev,
                 const unsigned int v0,
                 const std::vector <unsigned int> &to_index);
+        void DijkstraLimit (
+                std::vector<double>& d,
+                std::vector<double>& w,
+                std::vector<int>& prev,
+                const unsigned int v0,
+                const double &dlim);
         void AStar (std::vector<double>& d,
                 std::vector<double>& w,
                 std::vector<int>& prev,
