@@ -10,11 +10,16 @@ test_that("wp", {
 })
 
 test_that ("local wt_profile", {
+        expect_error (write_dodgr_wt_profile (),
+                      "file name must be given")
+
         f <- file.path (tempdir (), "wp")
         expect_silent (write_dodgr_wt_profile (f))
         n0 <- weight_streetnet (hampi, wt_profile = "foot")
         n1 <- weight_streetnet (hampi, wt_profile = "foot",
                               wt_profile_file = f)
+        attr (n0, "px") <- NULL
+        attr (n1, "px") <- NULL
         expect_identical (n0, n1)
 
         w <- dodgr::weighting_profiles
@@ -33,4 +38,12 @@ test_that ("local wt_profile", {
         expect_true (mean (n2$time_weighted) < mean (n0$time_weighted))
         expect_identical (n2$d, n0$d)
         expect_identical (n2$d_weighted, n0$d_weighted)
+
+        expect_error (weight_streetnet (hampi, wt_profile = 1:2),
+                      "wt_profile can only be one element")
+})
+
+test_that ("weight_streetnet wt_profile_file", {
+        expect_silent (graph <- weight_streetnet (hampi, wt_profile = 1))
+        expect_identical (graph$d, graph$d_weighted)
 })
